Name:		star
Version:	1.6
Release:	%mkrel 4
Summary:	An archiving tool with ACL support
Source:		https://download.sourceforge.net/s-tar/%{name}-%{version}.tar.bz2
License:	GPLv2+ LGPLv2+ CDDL
Group:		Archiving/Backup
BuildRequires:	libattr-devel
BuildRequires:	libacl-devel
BuildRequires:	pkgconfig(ext2fs)

%description
Star supports several tar archive formats (including ustar,
GNU tar and new POSIX format). It's faster than other tar
implementations due to advanced buffering.
Star is also the only tar implementation under Linux capable
of archiving Access Control Lists.

%package devel
Summary:        An archiving tool with ACL devel support
Group:          Archiving/Backup

%description devel
Star supports several tar archive formats (including ustar,
GNU tar and new POSIX format). It's faster than other tar
implementations due to advanced buffering.
Star is also the only tar implementation under Linux capable
of archiving Access Control Lists.

%prep
%setup -q

for PLAT in %{arm} aarch64 x86_64; do
    for AFILE in gcc cc; do
            [ ! -e RULES/${PLAT}-linux-${AFILE}.rul ] \
            && ln -s i586-linux-${AFILE}.rul RULES/${PLAT}-linux-${AFILE}.rul
    done
done

%build
# install runs build again

%install
make COPTX="%optflags -DTRY_EXT2_FS" \
     LDOPTX="%{ldflags}" \
     GMAKE_NOWARN=true \
     MANDIR=man \
     PARCH=%{_target_cpu} \
     K_ARCH=%{_target_cpu} \
     DEFCCOM=gcc \
     COPTGPROF= \
     INS_BASE=%{_prefix} \
     RUNPATH= \
     DESTDIR=%{buildroot} \
     install

# The following files conflict with GNU tar & mtr
rm -f ${RPM_BUILD_ROOT}/%{_bindir}/{,us}tar
rm -f ${RPM_BUILD_ROOT}/%{_bindir}/mt
rm -f ${RPM_BUILD_ROOT}/%{_mandir}/man1/match.1
# The following files conflict with the rmt package
rm -f ${RPM_BUILD_ROOT}/%{_sbindir}/rmt
# The following devel files conflict with cdrecord
rm -f ${RPM_BUILD_ROOT}/%{_includedir}/avoffset.h
rm -f ${RPM_BUILD_ROOT}/%{_libdir}/libdeflt.a
rm -f ${RPM_BUILD_ROOT}/%{_libdir}/libschily.a

# The other libs may be in the wrong place
if [ _"%{_libdir}" != _"/usr/lib" ]; then
	mkdir -p ${RPM_BUILD_ROOT}/%{_libdir}
	mv ${RPM_BUILD_ROOT}/usr/lib/* ${RPM_BUILD_ROOT}/%{_libdir}
fi

# fwang: I don't know why it installs to here
rm -f ${RPM_BUILD_ROOT}%{_datadir}/doc/rmt/default-rmt.sample
# Removing it now, it's done below
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/doc/star

%files
%doc AN-%{version} README COPYING
%doc READMEs/README.linux star/README.*
%doc star/STARvsGNUTAR
%doc STATUS.alpha TODO
%{_bindir}/gnutar
%{_bindir}/tartest
%{_bindir}/scpio
%{_bindir}/spax
%{_bindir}/smt
%{_bindir}/star
%{_bindir}/star_sym
%{_bindir}/suntar
%{_mandir}/man1/*.1*
%{_sysconfdir}/default/*

%files devel
%{_includedir}/schily/*.h
%{_includedir}/schily/*/*.h
%{_libdir}/lib*.a
%{_libdir}/profiled/*.a
%{_mandir}/man3/*
# This conflicts with man-pages
%exclude %{_mandir}/man3/error.3.*
%{_mandir}/man5/*


%changelog
* Thu Mar 24 2022 umeabot <umeabot> 1.6-4.mga9
+ Revision: 1824383
- Mageia 9 Mass Rebuild

* Tue Feb 02 2021 pterjan <pterjan> 1.6-3.mga8
+ Revision: 1674570
- Drop man3/error.3.xz which conflicts with man-pages

* Sat Sep 26 2020 wally <wally> 1.6-2.mga8
+ Revision: 1630692
- disable profiling
- fix buildroot definition in binaries
+ pterjan <pterjan>
- Remove (incorrect) rpath
- Force target cpu to allow building for armv7hl on armv8 cpu

* Mon Aug 10 2020 bcornec <bcornec> 1.6-1.mga8
+ Revision: 1613097
- Fix build options as using -pg conflicts with -fomit-frame-pointer
- Update to upstream start 1.6

* Fri Feb 14 2020 umeabot <umeabot> 1.5.3-9.mga8
+ Revision: 1517174
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 1.5.3-8.mga7
+ Revision: 1301184
- Mageia 7 Mass Rebuild

* Sun Jul 29 2018 wally <wally> 1.5.3-7.mga7
+ Revision: 1245772
- add build fixes from Fedora

* Mon Apr 16 2018 luigiwalser <luigiwalser> 1.5.3-6.mga7
+ Revision: 1219115
- also use our ldflags

* Sun Sep 03 2017 daviddavid <daviddavid> 1.5.3-5.mga7
+ Revision: 1151026
- honor user CFLAGS thus fixing empty debugsourcefiles.list

* Fri Feb 05 2016 umeabot <umeabot> 1.5.3-4.mga6
+ Revision: 938542
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.5.3-3.mga5
+ Revision: 741937
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.5.3-2.mga5
+ Revision: 689336
- Mageia 5 Mass Rebuild

* Mon Aug 11 2014 bcornec <bcornec> 1.5.3-1.mga5
+ Revision: 661851
- Update to upstream star 1.5.3

* Wed Jul 02 2014 bcornec <bcornec> 1.5.2-2.mga5
+ Revision: 642290
- Fix i386 build for dyn libs which weren't installed at the right place + include /etc/default files
- Fix an installation issue on build system due to the lack of definition of the INS_RBASE variable
- Remove any rmt related file (rmt conflicts)
- libs are not installed in the right place by default for x86_64 so check and move them
- pass install params tat build time also to improve /etc/default issue
- Update star to upstream 1.5.2
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Tue Jul 23 2013 bcornec <bcornec> 1.5a89-3.mga4
+ Revision: 457411
- Solve a dependency issue preventing star installation with mga3 and later (rmt binary conflicting with the rmt package)

* Mon Jan 14 2013 umeabot <umeabot> 1.5a89-2.mga3
+ Revision: 382696
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Oct 31 2012 bcornec <bcornec> 1.5a89-1.mga3
+ Revision: 311699
- Fix a wrong prefix usage
- Remove a hardcoded Prefix for newly imported star
- imported package star

